@@ -98,7 +98,7 @@ samples.beta <- array(NA, c(n.keep, p))
 samples.re <- array(NA, c(n.keep, K))
 samples.tau2 <- array(NA, c(n.keep, 1))
 samples.sigma2 <- array(NA, c(n.keep, 1))
-samples.like <- array(NA, c(n.keep, K))
+samples.loglike <- array(NA, c(n.keep, K))
 samples.fitted <- array(NA, c(n.keep, K))
 if(n.miss>0) samples.Y <- array(NA, c(n.keep, n.miss))
 
@@ -118,7 +118,7 @@ sigma2.posterior.shape <- prior.sigma2[1] + 0.5 * K
 #### Set up the spatial quantities
 ##################################
 #### CAR quantities
-W.quants <- common.Wcheckformat(W, K)
+W.quants <- common.Wcheckformat(W)
 W <- W.quants$W
 W.triplet <- W.quants$W.triplet
 n.triplet <- W.quants$n.triplet
@@ -143,7 +143,7 @@ tau2.posterior.shape <- prior.tau2[1] + 0.5 * (K-n.islands)
 #### Start timer
     if(verbose)
     {
-    cat("Generating", n.keep, "post burnin and thinned (if requested) samples\n", sep = " ")
+    cat("Generating", n.keep, "post burnin and thinned (if requested) samples.\n", sep = " ")
     progressBar <- txtProgressBar(style = 3)
     percentage.points<-round((1:100/100)*n.sample)
     }else
@@ -243,9 +243,7 @@ tau2.posterior.shape <- prior.tau2[1] + 0.5 * (K-n.islands)
     lp <- as.numeric(X.standardised %*% beta) + phi + theta + offset
     prob <- exp(lp)  / (1 + exp(lp))
     fitted <- trials * prob
-    deviance.all <- dbinom(x=Y, size=trials, prob=prob, log=TRUE)
-    like <- exp(deviance.all)
-    deviance <- -2 * sum(deviance.all, na.rm=TRUE)  
+    loglike <- dbinom(x=Y, size=trials, prob=prob, log=TRUE)
 
 
     
@@ -259,7 +257,7 @@ tau2.posterior.shape <- prior.tau2[1] + 0.5 * (K-n.islands)
         samples.re[ele, ] <- phi + theta
         samples.tau2[ele, ] <- tau2
         samples.sigma2[ele, ] <- sigma2
-        samples.like[ele, ] <- like
+        samples.loglike[ele, ] <- loglike
         samples.fitted[ele, ] <- fitted
             if(n.miss>0) samples.Y[ele, ] <- Y.DA[which.miss==0]
         }else
@@ -304,7 +302,7 @@ tau2.posterior.shape <- prior.tau2[1] + 0.5 * (K-n.islands)
 ##### end timer
     if(verbose)
     {
-    cat("\nSummarising results")
+    cat("\nSummarising results.")
     close(progressBar)
     }else
     {}
@@ -334,7 +332,7 @@ deviance.fitted <- -2 * sum(dbinom(x=Y, size=trials, prob=mean.prob, log=TRUE),
 
 
 #### Model fit criteria
-modelfit <- common.modelfit(samples.like, deviance.fitted)
+modelfit <- common.modelfit(samples.loglike, deviance.fitted)
 
 
 #### transform the parameters back to the origianl covariate scale.
@@ -380,7 +378,7 @@ class(results) <- "CARBayes"
     if(verbose)
     {
     b<-proc.time()
-    cat(" finished in ", round(b[3]-a[3], 1), "seconds")
+    cat("Finished in ", round(b[3]-a[3], 1), "seconds.\n")
     }else
     {}
 return(results)
