@@ -108,7 +108,7 @@ samples.beta <- array(NA, c(n.keep, p))
 samples.phi <- array(NA, c(n.keep, K))
 samples.tau2 <- array(NA, c(n.keep, 1))
     if(!fix.rho) samples.rho <- array(NA, c(n.keep, 1))
-samples.like <- array(NA, c(n.keep, K))
+samples.loglike <- array(NA, c(n.keep, K))
 samples.fitted <- array(NA, c(n.keep, K))
     if(n.miss>0) samples.Y <- array(NA, c(n.keep, n.miss))
     
@@ -127,7 +127,7 @@ tau2.posterior.shape <- prior.tau2[1] + 0.5 * K
 #### Set up the spatial quantities
 ##################################
 #### CAR quantities
-W.quants <- common.Wcheckformat.leroux(W, K, fix.rho, rho)
+W.quants <- common.Wcheckformat(W)
 W <- W.quants$W
 W.triplet <- W.quants$W.triplet
 n.triplet <- W.quants$n.triplet
@@ -163,7 +163,7 @@ if(rho==1) tau2.posterior.shape <- prior.tau2[1] + 0.5 * (K-n.islands)
 #### Start timer
     if(verbose)
     {
-    cat("Generating", n.keep, "post burnin and thinned (if requested) samples\n", sep = " ")
+    cat("Generating", n.keep, "post burnin and thinned (if requested) samples.\n", sep = " ")
     progressBar <- txtProgressBar(style = 3)
     percentage.points<-round((1:100/100)*n.sample)
     }else
@@ -270,9 +270,7 @@ if(rho==1) tau2.posterior.shape <- prior.tau2[1] + 0.5 * (K-n.islands)
         lp <- as.numeric(X.standardised %*% beta) + phi + offset
         prob <- exp(lp)  / (1 + exp(lp))
         fitted <- trials * prob
-        deviance.all <- dbinom(x=Y, size=trials, prob=prob, log=TRUE)
-        like <- exp(deviance.all)
-        deviance <- -2 * sum(deviance.all, na.rm=TRUE)
+        loglike <- dbinom(x=Y, size=trials, prob=prob, log=TRUE)
         
         
         
@@ -286,7 +284,7 @@ if(rho==1) tau2.posterior.shape <- prior.tau2[1] + 0.5 * (K-n.islands)
             samples.phi[ele, ] <- phi
             samples.tau2[ele, ] <- tau2
                 if(!fix.rho) samples.rho[ele, ] <- rho
-            samples.like[ele, ] <- like
+            samples.loglike[ele, ] <- loglike
             samples.fitted[ele, ] <- fitted
                 if(n.miss>0) samples.Y[ele, ] <- Y.DA[which.miss==0]
             }else
@@ -333,7 +331,7 @@ if(rho==1) tau2.posterior.shape <- prior.tau2[1] + 0.5 * (K-n.islands)
 ##### end timer
     if(verbose)
     {
-    cat("\nSummarising results")
+    cat("\nSummarising results.")
     close(progressBar)
     }else
     {}
@@ -368,7 +366,7 @@ deviance.fitted <- -2 * sum(dbinom(x=Y, size=trials, prob=mean.prob, log=TRUE),
 
     
 #### Model fit criteria
-modelfit <- common.modelfit(samples.like, deviance.fitted)
+modelfit <- common.modelfit(samples.loglike, deviance.fitted)
     
 
 #### transform the parameters back to the origianl covariate scale.
@@ -422,7 +420,7 @@ class(results) <- "CARBayes"
     if(verbose)
     {
     b<-proc.time()
-    cat(" finished in ", round(b[3]-a[3], 1), "seconds")
+    cat("Finished in ", round(b[3]-a[3], 1), "seconds.\n")
     }else
     {}
 return(results)
