@@ -126,7 +126,7 @@ samples.tau2 <- array(NA, c(n.keep, 1))
 samples.Z <- array(NA, c(n.keep, K))
 samples.lambda <- array(NA, c(n.keep, G))
 samples.delta <- array(NA, c(n.keep, 1))
-samples.like <- array(NA, c(n.keep, K))
+samples.loglike <- array(NA, c(n.keep, K))
 samples.fitted <- array(NA, c(n.keep, K))
 
 
@@ -153,7 +153,7 @@ tau2.posterior.shape <- prior.tau2[1] + 0.5 * K
 #### Set up the spatial quantities
 ##################################
 #### CAR quantities
-W.quants <- common.Wcheckformat(W, K)
+W.quants <- common.Wcheckformat(W)
 W <- W.quants$W
 W.triplet <- W.quants$W.triplet
 n.triplet <- W.quants$n.triplet
@@ -169,7 +169,7 @@ W.begfin <- W.quants$W.begfin
 #### Start timer
      if(verbose)
      {
-     cat("Generating", n.keep, "post burnin and thinned (if requested) samples\n", sep = " ")
+     cat("Generating", n.keep, "post burnin and thinned (if requested) samples.\n", sep = " ")
      progressBar <- txtProgressBar(style = 3)
      percentage.points<-round((1:100/100)*n.sample)
      }else
@@ -298,9 +298,7 @@ W.begfin <- W.quants$W.begfin
     lp <- lambda[Z] + phi + regression.vec + offset
     prob <- exp(lp)  / (1 + exp(lp))
     fitted <- trials * prob
-    deviance.all <- dbinom(x=Y, size=trials, prob=prob, log=TRUE)
-    like <- exp(deviance.all)
-    deviance <- -2 * sum(deviance.all, na.rm=TRUE)  
+    loglike <- dbinom(x=Y, size=trials, prob=prob, log=TRUE)
 
          
          
@@ -315,7 +313,7 @@ W.begfin <- W.quants$W.begfin
         samples.tau2[ele, ] <- tau2
         samples.Z[ele, ] <- Z
         samples.delta[ele, ] <- delta
-        samples.like[ele, ] <- like
+        samples.loglike[ele, ] <- loglike
         samples.fitted[ele, ] <- fitted
         if(!is.null(X)) samples.beta[ele, ] <- beta    
         }else
@@ -369,7 +367,7 @@ W.begfin <- W.quants$W.begfin
 ##### end timer
     if(verbose)
     {
-    cat("\nSummarising results")
+    cat("\nSummarising results.")
     close(progressBar)
     }else
     {}
@@ -416,7 +414,7 @@ deviance.fitted <- -2 * sum(dbinom(x=Y, size=trials, prob=mean.prob, log=TRUE))
 
 
 #### Model fit criteria
-modelfit <- common.modelfit(samples.like, deviance.fitted)
+modelfit <- common.modelfit(samples.loglike, deviance.fitted)
 
      
 #### transform the parameters back to the origianl covariate scale.
@@ -474,7 +472,7 @@ residuals <- data.frame(response=response.residuals, pearson=pearson.residuals)
 model.string <- c("Likelihood model - Binomial (logit link function)", "\nRandom effects  model - Localised CAR model\n")
 if(is.null(X)) samples.beta.orig = NA
 
-samples <- list(beta=mcmc(samples.beta.orig), phi=mcmc(samples.phi), lambda=mcmc(samples.lambda), Z=mcmc(samples.Z), tau2=mcmc(samples.tau2), delta=mcmc(samples.delta), fitted=mcmc(samples.fitted))          
+samples <- list(beta=mcmc(samples.beta.orig), phi=mcmc(samples.phi), lambda=mcmc(samples.lambda), Z=mcmc(samples.Z), tau2=mcmc(samples.tau2), delta=mcmc(samples.delta), fitted=mcmc(samples.fitted), Y=NA)          
 results <- list(summary.results=summary.results, samples=samples, fitted.values=fitted.values, residuals=residuals, modelfit=modelfit, accept=accept.final, localised.structure=mean.Z,  formula=formula, model=model.string, X=X)
 class(results) <- "CARBayes"
 
@@ -482,7 +480,7 @@ class(results) <- "CARBayes"
     if(verbose)
     {
     b<-proc.time()
-    cat(" finished in ", round(b[3]-a[3], 1), "seconds")
+    cat("Finished in ", round(b[3]-a[3], 1), "seconds.\n")
     }else
     {}
 return(results)
