@@ -114,7 +114,7 @@ samples.nu2 <- array(NA, c(n.keep, J))
 samples.phi <- array(NA, c(n.keep, N.all))
 samples.Sigma <- array(NA, c(n.keep, J, J))
     if(!fix.rho) samples.rho <- array(NA, c(n.keep, 1))
-samples.like <- array(NA, c(n.keep, N.all))
+samples.loglike <- array(NA, c(n.keep, N.all))
 samples.fitted <- array(NA, c(n.keep, N.all))
     if(n.miss>0) samples.Y <- array(NA, c(n.keep, n.miss))
     
@@ -132,7 +132,7 @@ nu2.posterior.shape <- prior.nu2[1] + 0.5 * K
 #### Set up the spatial quantities
 ##################################
 #### CAR quantities
-W.quants <- common.Wcheckformat.leroux(W, K, fix.rho, rho)
+W.quants <- common.Wcheckformat(W)
 W <- W.quants$W
 W.triplet <- W.quants$W.triplet
 n.triplet <- W.quants$n.triplet
@@ -185,7 +185,7 @@ data.precision <- t(X.standardised) %*% X.standardised
 #### Start timer
     if(verbose)
     {
-    cat("Generating", n.keep, "post burnin and thinned (if requested) samples\n", sep = " ")
+    cat("Generating", n.keep, "post burnin and thinned (if requested) samples.\n", sep = " ")
     progressBar <- txtProgressBar(style = 3)
     percentage.points<-round((1:100/100)*n.sample)
     }else
@@ -297,9 +297,7 @@ data.precision <- t(X.standardised) %*% X.standardised
         ## Calculate the deviance
         #########################
         fitted <- regression + phi + offset
-        deviance.all <- dnorm(x=as.numeric(t(Y)), mean=as.numeric(t(fitted)), sd=rep(sqrt(nu2), K), log=TRUE)
-        like <- exp(deviance.all)
-        deviance <- -2 * sum(deviance.all, na.rm=TRUE)  
+        loglike <- dnorm(x=as.numeric(t(Y)), mean=as.numeric(t(fitted)), sd=rep(sqrt(nu2), K), log=TRUE)
 
         
         ###################
@@ -313,7 +311,7 @@ data.precision <- t(X.standardised) %*% X.standardised
             samples.phi[ele, ] <- as.numeric(t(phi))
             samples.Sigma[ele, , ] <- Sigma
             if(!fix.rho) samples.rho[ele, ] <- rho
-            samples.like[ele, ] <- like
+            samples.loglike[ele, ] <- loglike
             samples.fitted[ele, ] <- as.numeric(t(fitted))
             if(n.miss>0) samples.Y[ele, ] <- Y.DA[miss.locator]
         }else
@@ -351,7 +349,7 @@ data.precision <- t(X.standardised) %*% X.standardised
     ##### end timer
     if(verbose)
     {
-        cat("\nSummarising results")
+        cat("\nSummarising results.")
         close(progressBar)
     }else
     {}
@@ -384,7 +382,7 @@ deviance.fitted <- -2 * sum(dnorm(as.numeric(t(Y)), mean = as.numeric(t(fitted.m
 
     
 #### Model fit criteria
-modelfit <- common.modelfit(samples.like, deviance.fitted)
+modelfit <- common.modelfit(samples.loglike, deviance.fitted)
 
 
 #### transform the parameters back to the origianl covariate scale.
@@ -475,7 +473,7 @@ class(results) <- "CARBayes"
     if(verbose)
     {
     b<-proc.time()
-    cat(" finished in ", round(b[3]-a[3], 1), "seconds")
+    cat("Finished in ", round(b[3]-a[3], 1), "seconds.\n")
     }else
     {}
 return(results)
