@@ -94,7 +94,7 @@ samples.phi <- array(NA, c(n.keep, K))
 samples.nu2 <- array(NA, c(n.keep, 1))
 samples.tau2 <- array(NA, c(n.keep, 1))
 samples.alpha <- array(NA, c(n.keep, q))
-samples.like <- array(NA, c(n.keep, K))
+samples.loglike <- array(NA, c(n.keep, K))
 samples.fitted <- array(NA, c(n.keep, K))
     if(n.miss>0) samples.Y <- array(NA, c(n.keep, n.miss))
 
@@ -112,7 +112,7 @@ nu2.posterior.shape <- prior.nu2[1] + 0.5*K
 #### Set up the spatial quantities
 ##################################
 #### CAR quantities
-W.quants <- common.Wcheckformat.disimilarity(W, K)
+W.quants <- common.Wcheckformat.disimilarity(W)
 W <- W.quants$W
 W.triplet <- W.quants$W.triplet
 n.triplet <- W.quants$n.triplet
@@ -172,7 +172,7 @@ data.precision.beta <- t(X.standardised) %*% X.standardised
 #### Start timer
      if(verbose)
      {
-     cat("Generating", n.keep, "post burnin and thinned (if requested) samples\n", sep = " ")
+     cat("Generating", n.keep, "post burnin and thinned (if requested) samples.\n", sep = " ")
      progressBar <- txtProgressBar(style = 3)
      percentage.points<-round((1:100/100)*n.sample)
      }else
@@ -283,9 +283,7 @@ data.precision.beta <- t(X.standardised) %*% X.standardised
     ## Calculate the deviance
     #########################
     fitted <- as.numeric(X.standardised %*% beta) + phi + offset
-    deviance.all <- dnorm(Y, mean = fitted, sd = rep(sqrt(nu2),K), log=TRUE)
-    like <- exp(deviance.all)
-    deviance <- -2 * sum(deviance.all, na.rm=TRUE)  
+    loglike <- dnorm(Y, mean = fitted, sd = rep(sqrt(nu2),K), log=TRUE)
 
 
     
@@ -300,7 +298,7 @@ data.precision.beta <- t(X.standardised) %*% X.standardised
         samples.nu2[ele, ] <- nu2
         samples.tau2[ele, ] <- tau2
         samples.alpha[ele, ] <- alpha
-        samples.like[ele, ] <- like
+        samples.loglike[ele, ] <- loglike
         samples.fitted[ele, ] <- fitted
             if(n.miss>0) samples.Y[ele, ] <- Y.DA[which.miss==0]
         }else
@@ -336,7 +334,7 @@ data.precision.beta <- t(X.standardised) %*% X.standardised
 ##### end timer
     if(verbose)
     {
-    cat("\nSummarising results")
+    cat("\nSummarising results.")
     close(progressBar)
     }else
     {}
@@ -361,7 +359,7 @@ deviance.fitted <- -2 * sum(dnorm(Y, mean = fitted.mean, sd = rep(sqrt(nu2.mean)
 
    
 #### Model fit criteria
-modelfit <- common.modelfit(samples.like, deviance.fitted)
+modelfit <- common.modelfit(samples.loglike, deviance.fitted)
 
 
 #### transform the parameters back to the origianl covariate scale.
@@ -459,12 +457,23 @@ W.posterior <- array(NA, c(K,K))
 
 
 ## Compile and return the results
-    if(W.binary)
+## Generate the dissimilarity equation
+    if(q==1)
     {
-    model.string <- c("Likelihood model - Gaussian (identity link function)", "\nRandom effects model - Binary dissimilarity CAR", "\nDissimilarity metrics - ", rownames(summary.alpha), "\n")     
+    dis.eq <- rownames(summary.results)[nrow(summary.results)]    
     }else
     {
-    model.string <- c("Likelihood model - Gaussian (identity link function)", "\nRandom effects model - Non-binary dissimilarity CAR", "\nDissimilarity metrics - ", rownames(summary.alpha), "\n")     
+    dis.eq <- paste(rownames(summary.alpha), "+")
+    len <- length(dis.eq)
+    dis.eq[len] <- substr(dis.eq[len],1,nchar(dis.eq[2])-1)    
+    }
+
+if(W.binary)
+    {
+    model.string <- c("Likelihood model - Gaussian (identity link function)", "\nRandom effects model - Binary dissimilarity CAR", "\nDissimilarity metrics - ", dis.eq, "\n")     
+    }else
+    {
+    model.string <- c("Likelihood model - Gaussian (identity link function)", "\nRandom effects model - Non-binary dissimilarity CAR", "\nDissimilarity metrics - ", dis.eq, "\n")     
     }
 
     if(n.miss==0) samples.Y = NA
@@ -477,7 +486,7 @@ class(results) <- "CARBayes"
     if(verbose)
     {
     b<-proc.time()
-    cat(" finished in ", round(b[3]-a[3], 1), "seconds")
+    cat("Finished in ", round(b[3]-a[3], 1), "seconds.\n")
     }else
     {}
 return(results)
