@@ -38,7 +38,7 @@ Y.DA <- Y
 
 #### CAR quantities
 K <- length(unique(ind.area))
-W.quants <- common.Wcheckformat.leroux(W, K, fix.rho, rho)
+W.quants <- common.Wcheckformat(W)
 W <- W.quants$W
 W.triplet <- W.quants$W.triplet
 n.triplet <- W.quants$n.triplet
@@ -153,7 +153,7 @@ samples.tau2 <- array(NA, c(n.keep, 1))
     if(!is.null(ind.re)) samples.psi <- array(NA, c(n.keep, q))
     if(!is.null(ind.re)) samples.sigma2 <- array(NA, c(n.keep, 1))
     if(!fix.rho) samples.rho <- array(NA, c(n.keep, 1))
-samples.like <- array(NA, c(n.keep, n))
+samples.loglike <- array(NA, c(n.keep, n))
 samples.fitted <- array(NA, c(n.keep, n))
     if(n.miss>0) samples.Y <- array(NA, c(n.keep, n.miss))
 
@@ -195,7 +195,7 @@ data.precision.beta <- t(X.standardised) %*% X.standardised
 #### Start timer
     if(verbose)
     {
-    cat("Generating", n.keep, "post burnin and thinned (if requested) samples\n", sep = " ")
+    cat("Generating", n.keep, "post burnin and thinned (if requested) samples.\n", sep = " ")
     progressBar <- txtProgressBar(style = 3)
     percentage.points<-round((1:100/100)*n.sample)
     }else
@@ -317,11 +317,8 @@ data.precision.beta <- t(X.standardised) %*% X.standardised
     ## Calculate the deviance
     #########################
     fitted <- as.numeric(X.standardised %*% beta) + phi.extend + offset + psi.extend
-    deviance.all <- dnorm(Y, mean = fitted, sd = rep(sqrt(nu2),n), log=TRUE)
-    like <- exp(deviance.all)
-    deviance <- -2 * sum(deviance.all, na.rm=TRUE)  
-        
-        
+    loglike <- dnorm(Y, mean = fitted, sd = rep(sqrt(nu2),n), log=TRUE)
+
         
     ###################
     ## Save the results
@@ -336,7 +333,7 @@ data.precision.beta <- t(X.standardised) %*% X.standardised
             if(!is.null(ind.re))  samples.psi[ele, ] <- psi
             if(!is.null(ind.re)) samples.sigma2[ele, ] <- sigma2
             if(!fix.rho) samples.rho[ele, ] <- rho
-        samples.like[ele, ] <- like
+        samples.loglike[ele, ] <- loglike
         samples.fitted[ele, ] <- fitted
             if(n.miss>0) samples.Y[ele, ] <- Y.DA[which.miss==0]
         }else
@@ -375,7 +372,7 @@ data.precision.beta <- t(X.standardised) %*% X.standardised
 ##### end timer
     if(verbose)
     {
-    cat("\nSummarising results")
+    cat("\nSummarising results.")
     close(progressBar)
     }else
     {}
@@ -423,7 +420,7 @@ deviance.fitted <- -2 * sum(dnorm(Y, mean = fitted.mean, sd = rep(sqrt(nu2.mean)
 
     
 #### Model fit criteria
-modelfit <- common.modelfit(samples.like, deviance.fitted)
+modelfit <- common.modelfit(samples.loglike, deviance.fitted)
 
     
 #### transform the parameters back to the origianl covariate scale.
@@ -496,7 +493,7 @@ class(results) <- "CARBayes"
     if(verbose)
     {
     b<-proc.time()
-    cat(" finished in ", round(b[3]-a[3], 1), "seconds")
+    cat("Finished in ", round(b[3]-a[3], 1), "seconds.\n")
     }else
     {}
 return(results)
