@@ -109,7 +109,7 @@ samples.beta <- array(NA, c(n.keep, p))
 samples.phi <- array(NA, c(n.keep, K))
 samples.tau2 <- array(NA, c(n.keep, 1))
 samples.alpha <- array(NA, c(n.keep, q))
-samples.like <- array(NA, c(n.keep, K))
+samples.loglike <- array(NA, c(n.keep, K))
 samples.fitted <- array(NA, c(n.keep, K))
 if(n.miss>0) samples.Y <- array(NA, c(n.keep, n.miss))
 
@@ -127,7 +127,7 @@ tau2.posterior.shape <- prior.tau2[1] + 0.5 * K
 #### Set up the spatial quantities
 ##################################
 #### CAR quantities
-W.quants <- common.Wcheckformat.disimilarity(W, K)
+W.quants <- common.Wcheckformat.disimilarity(W)
 W <- W.quants$W
 W.triplet <- W.quants$W.triplet
 n.triplet <- W.quants$n.triplet
@@ -176,7 +176,7 @@ det.Q <- sum(log(diag(chol.spam(Q))))
 #### Start timer
     if(verbose)
     {
-    cat("Generating", n.keep, "post burnin and thinned (if requested) samples\n", sep = " ")
+    cat("Generating", n.keep, "post burnin and thinned (if requested) samples.\n", sep = " ")
     progressBar <- txtProgressBar(style = 3)
     percentage.points<-round((1:100/100)*n.sample)
     }else
@@ -293,9 +293,8 @@ det.Q <- sum(log(diag(chol.spam(Q))))
     #########################
     lp <- as.numeric(X.standardised %*% beta) + phi + offset
     fitted <- exp(lp)
-    deviance.all <- dpois(x=as.numeric(Y), lambda=fitted, log=TRUE)
-    like <- exp(deviance.all)
-    deviance <- -2 * sum(deviance.all, na.rm=TRUE)  
+    loglike <- dpois(x=as.numeric(Y), lambda=fitted, log=TRUE)
+ 
 
 
     
@@ -309,7 +308,7 @@ det.Q <- sum(log(diag(chol.spam(Q))))
         samples.phi[ele, ] <- phi
         samples.tau2[ele, ] <- tau2
         samples.alpha[ele, ] <- alpha
-        samples.like[ele, ] <- like
+        samples.loglike[ele, ] <- loglike
         samples.fitted[ele, ] <- fitted
             if(n.miss>0) samples.Y[ele, ] <- Y.DA[which.miss==0]
         }else
@@ -353,7 +352,7 @@ det.Q <- sum(log(diag(chol.spam(Q))))
 ##### end timer
     if(verbose)
     {
-    cat("\nSummarising results")
+    cat("\nSummarising results.")
     close(progressBar)
     }else
     {}
@@ -380,7 +379,7 @@ deviance.fitted <- -2 * sum(dpois(x=Y, lambda=fitted.mean, log=TRUE), na.rm=TRUE
 
 
 #### Model fit criteria
-modelfit <- common.modelfit(samples.like, deviance.fitted)
+modelfit <- common.modelfit(samples.loglike, deviance.fitted)
 
 
 #### Transform the parameters back to the origianl covariate scale.
@@ -477,12 +476,25 @@ W.posterior <- array(NA, c(K,K))
 
 
 #### Compile and return the results
-    if(W.binary)
+## Generate the dissimilarity equation
+    if(q==1)
     {
-    model.string <- c("Likelihood model - Poisson (log link function)", "\nRandom effects model - Binary dissimilarity CAR", "\nDissimilarity metrics - ", rownames(summary.alpha), "\n")     
+    dis.eq <- rownames(summary.results)[nrow(summary.results)]    
     }else
     {
-    model.string <- c("Likelihood model - Poisson (log link function)", "\nRandom effects model - Non-binary dissimilarity CAR", "\nDissimilarity metrics - ", rownames(summary.alpha), "\n")     
+    dis.eq <- paste(rownames(summary.alpha), "+")
+    len <- length(dis.eq)
+    dis.eq[len] <- substr(dis.eq[len],1,nchar(dis.eq[2])-1)    
+    }
+
+
+
+    if(W.binary)
+    {
+    model.string <- c("Likelihood model - Poisson (log link function)", "\nRandom effects model - Binary dissimilarity CAR", "\nDissimilarity metrics - ", dis.eq, "\n")     
+    }else
+    {
+    model.string <- c("Likelihood model - Poisson (log link function)", "\nRandom effects model - Non-binary dissimilarity CAR", "\nDissimilarity metrics - ", dis.eq, "\n")     
     }
 
     if(n.miss==0) samples.Y = NA
@@ -494,7 +506,7 @@ class(results) <- "CARBayes"
     if(verbose)
     {
     b<-proc.time()
-    cat(" finished in ", round(b[3]-a[3], 1), "seconds")
+    cat("Finished in ", round(b[3]-a[3], 1), "seconds.\n")
     }else
     {}
 return(results)
