@@ -64,7 +64,7 @@ fitted <- exp(as.numeric(X.standardised %*% beta) + offset)
 #### Matrices to store samples   
 n.keep <- floor((n.sample - burnin)/thin)
 samples.beta <- array(NA, c(n.keep, p))
-samples.like <- array(NA, c(n.keep, K))
+samples.loglike <- array(NA, c(n.keep, K))
 samples.fitted <- array(NA, c(n.keep, K))
     if(n.miss>0) samples.Y <- array(NA, c(n.keep, n.miss))
     
@@ -82,7 +82,7 @@ proposal.sd.beta <- 0.01
 #### Start timer
     if(verbose)
     {
-    cat("Generating", n.keep, "post burnin and thinned (if requested) samples\n", sep = " ")
+    cat("Generating", n.keep, "post burnin and thinned (if requested) samples.\n", sep = " ")
     progressBar <- txtProgressBar(style = 3)
     percentage.points<-round((1:100/100)*n.sample)
     }else
@@ -127,9 +127,8 @@ proposal.sd.beta <- 0.01
     #########################
     lp <- as.numeric(X.standardised %*% beta) + offset
     fitted <- exp(lp)
-    deviance.all <- dpois(x=as.numeric(Y), lambda=fitted, log=TRUE)
-    like <- exp(deviance.all)
-    deviance <- -2 * sum(deviance.all, na.rm=TRUE)  
+    loglike <- dpois(x=as.numeric(Y), lambda=fitted, log=TRUE)
+
         
         
         
@@ -140,7 +139,7 @@ proposal.sd.beta <- 0.01
         {
         ele <- (j - burnin) / thin
         samples.beta[ele, ] <- beta
-        samples.like[ele, ] <- like
+        samples.loglike[ele, ] <- loglike
         samples.fitted[ele, ] <- fitted
             if(n.miss>0) samples.Y[ele, ] <-Y.DA[which.miss==0]
         }else
@@ -182,7 +181,7 @@ proposal.sd.beta <- 0.01
 #### end timer
     if(verbose)
     {
-    cat("\nSummarising results")
+    cat("\nSummarising results.")
     close(progressBar)
     }else
     {}
@@ -205,7 +204,7 @@ deviance.fitted <- -2 * sum(dpois(x=Y, lambda=fitted.mean, log=TRUE), na.rm=TRUE
 
 
 #### Model fit criteria
-modelfit <- common.modelfit(samples.like, deviance.fitted)
+modelfit <- common.modelfit(samples.loglike, deviance.fitted)
 
     
 #### transform the parameters back to the origianl covariate scale.
@@ -243,7 +242,7 @@ class(results) <- "CARBayes"
     if(verbose)
     {
     b<-proc.time()
-    cat(" finished in ", round(b[3]-a[3], 1), "seconds")
+    cat("Finished in ", round(b[3]-a[3], 1), "seconds.\n")
     }else
     {}
 return(results)
