@@ -94,7 +94,7 @@ samples.beta <- array(NA, c(n.keep, p))
 samples.phi <- array(NA, c(n.keep, K))
 samples.tau2 <- array(NA, c(n.keep, 1))
     if(!fix.rho) samples.rho <- array(NA, c(n.keep, 1))
-samples.like <- array(NA, c(n.keep, K))
+samples.loglike <- array(NA, c(n.keep, K))
 samples.fitted <- array(NA, c(n.keep, K))
     if(n.miss>0) samples.Y <- array(NA, c(n.keep, n.miss))
     
@@ -113,7 +113,7 @@ tau2.posterior.shape <- prior.tau2[1] + 0.5 * K
 #### Set up the spatial quantities
 ##################################
 #### CAR quantities
-W.quants <- common.Wcheckformat.leroux(W, K, fix.rho, rho)
+W.quants <- common.Wcheckformat(W)
 W <- W.quants$W
 W.triplet <- W.quants$W.triplet
 n.triplet <- W.quants$n.triplet
@@ -149,7 +149,7 @@ n.islands <- max(W.islands$nc)
 #### Start timer
     if(verbose)
     {
-    cat("Generating", n.keep, "post burnin and thinned (if requested) samples\n", sep = " ")
+    cat("Generating", n.keep, "post burnin and thinned (if requested) samples.\n", sep = " ")
     progressBar <- txtProgressBar(style = 3)
     percentage.points<-round((1:100/100)*n.sample)
     }else
@@ -256,11 +256,9 @@ n.islands <- max(W.islands$nc)
     #########################
     lp <- as.numeric(regression) + phi + offset
     fitted <- exp(lp)
-    deviance.all <- dpois(x=as.numeric(Y), lambda=fitted, log=TRUE)
-    like <- exp(deviance.all)
-    deviance <- -2 * sum(deviance.all, na.rm=TRUE)  
-        
-        
+    loglike <- dpois(x=as.numeric(Y), lambda=fitted, log=TRUE)
+
+
     
     ###################
     ## Save the results
@@ -272,7 +270,7 @@ n.islands <- max(W.islands$nc)
         samples.phi[ele, ] <- phi
         samples.tau2[ele, ] <- tau2
             if(!fix.rho) samples.rho[ele, ] <- rho
-        samples.like[ele, ] <- like
+        samples.loglike[ele, ] <- loglike
         samples.fitted[ele, ] <- fitted
             if(n.miss>0) samples.Y[ele, ] <- Y.DA[which.miss==0]
         }else
@@ -317,7 +315,7 @@ n.islands <- max(W.islands$nc)
 ##### end timer
     if(verbose)
     {
-    cat("\nSummarising results")
+    cat("\nSummarising results.")
     close(progressBar)
     }else
     {}
@@ -351,7 +349,8 @@ deviance.fitted <- -2 * sum(dpois(x=Y, lambda=fitted.mean, log=TRUE), na.rm=TRUE
 
 
 #### Model fit criteria
-modelfit <- common.modelfit(samples.like, deviance.fitted)
+modelfit <- common.modelfit(samples.loglike, deviance.fitted)
+
 
 
 #### Transform the parameters back to the origianl covariate scale.
@@ -404,7 +403,7 @@ class(results) <- "CARBayes"
     if(verbose)
     {
     b<-proc.time()
-    cat(" finished in ", round(b[3]-a[3], 1), "seconds")
+    cat("Finished in ", round(b[3]-a[3], 1), "seconds.\n")
     }else
     {}
 return(results)
